@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021-2023 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Divides 0.05;
+package Syntax::Operator::Divides 0.06;
 
 use v5.14;
 use warnings;
@@ -98,7 +98,7 @@ sub apply
    foreach (qw( is_divisor )) {
       next unless delete $syms{$_};
 
-      $callerpkg //= meta::get_package( $caller );
+      $callerpkg //= meta::package->get( $caller );
 
       $on ? $callerpkg->add_symbol( '&'.$_ => \&{$_} )
           : $callerpkg->remove_symbol( '&'.$_ );
